<?php
namespace NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget;

use \Magento\Backend\App\Action;
use \Magento\Backend\Model\View\Result\Redirect;
use \Magento\Framework\App\ObjectManager;
use \Magento\Framework\Controller\ResultFactory;
use \Magento\Backend\App\Action\Context;
use \Magento\Framework\Exception\LocalizedException;
use \Magento\Ui\Component\MassAction\Filter;
use \NicolasBejean\CategoryWidget\Model\CategoryWidget as Model;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget as ResourceModel;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Collection;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\CollectionFactory;
use \Exception;

/**
 * Class MassDisable
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class MassDisable extends Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'NicolasBejean_CategoryWidget::global';

    /**
     * @var Filter
     */
    protected $filter;

    /**
     * @var CollectionFactory
     */
    protected $collectionFactory;

    /**
     * @param Context               $context
     * @param Filter                $filter
     * @param CollectionFactory     $collectionFactory
     */
    public function __construct(
        Context                     $context,
        Filter                      $filter,
        CollectionFactory           $collectionFactory
    )
    {
        $this->filter               = $filter;
        $this->collectionFactory    = $collectionFactory;

        parent::__construct($context);
    }

    /**
     * Execute action
     *
     * @return Redirect
     * @throws LocalizedException|Exception
     */
    public function execute()
    {
        /** @var Collection $collection */
        $collection = $this->filter->getCollection($this->collectionFactory->create());
        $collectionSize = $collection->getSize();

        /** @var ResourceModel $resourceModel */
        $resourceModel = ObjectManager::getInstance()->get(ResourceModel::class);

        /** @var Model $item */
        foreach ($collection as $item) {
            $item->setIsActive(false);
            $resourceModel->save($item);
        }

        $this->messageManager->addSuccessMessage(
            __('A total of %1 record(s) have been disabled.', $collectionSize)
        );

        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return $resultRedirect->setPath('*/*/');
    }
}
