<?php
namespace NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget\Widget;

use \Magento\Backend\App\Action;
use \Magento\Backend\App\Action\Context;
use \Magento\Framework\Controller\Result\Raw;
use \Magento\Framework\Controller\ResultInterface;
use \Magento\Framework\View\Layout;
use \Magento\Framework\View\LayoutFactory;
use \Magento\Framework\Controller\Result\RawFactory;
use \NicolasBejean\CategoryWidget\Block\Adminhtml\CategoryWidget\Widget\Chooser as WidgetChooser;

/**
 * Class Chooser
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget\Widget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class Chooser extends Action
{
    /**
     * Authorization level of a basic admin session
     */
    const ADMIN_RESOURCE = 'Magento_Widget::widget_instance';

    /**
     * @var LayoutFactory
     */
    protected $layoutFactory;

    /**
     * @var RawFactory
     */
    protected $resultRawFactory;

    /**
     * @param Context           $context
     * @param LayoutFactory     $layoutFactory
     * @param RawFactory        $resultRawFactory
     */
    public function __construct
    (
        Context                 $context,
        LayoutFactory           $layoutFactory,
        RawFactory              $resultRawFactory
    ) {
        $this->layoutFactory    = $layoutFactory;
        $this->resultRawFactory = $resultRawFactory;

        parent::__construct($context);
    }

    /**
     * Chooser Source action
     *
     * @return ResultInterface
     */
    public function execute()
    {
        /** @var Layout $layout */
        $layout = $this->layoutFactory->create();

        $uniqId = $this->getRequest()->getParam('uniq_id');
        $pagesGrid = $layout->createBlock(
            WidgetChooser::class,
            '',
            ['data' => ['id' => $uniqId]]
        );

        /** @var Raw $resultRaw */
        $resultRaw = $this->resultRawFactory->create();
        $resultRaw->setContents($pagesGrid->toHtml());
        return $resultRaw;
    }
}
